clear all

%Loading data from file and write to time vector and displacement vector
load elem_force3.plo
t = elem_force3(:,1);
d = elem_force3(:,2);
n = length(t);

%Time step used in USFOS analysis
dt = (t(end) - t(1))/(n-1);

%Finding zero-up-crossing points
k = 0; %counting the number of zero-up-crossing points
Z = [];
for i = 1:n-1
    if d(i)<0 && d(i+1)>0
        k = k+1;
        Z(k) = i;  %Last point before zero-up-crossing
        TZ(k) = Z(k)*dt-d(i)*dt/(d(i+1)-d(i)); %Time for zero-up-crossing 
                                               %assuming linear increasment
                                               %between the two points
    end
end

m = length(Z); %Number of zero-up-crossings

%Storing the wave periods in T
T = zeros(1,m-1);
for i = 1:m-1
    T(i) = dt*(Z(i+1)-Z(i));  %Wave periods
end

%Finding max and min diplacement in each interval
[mx,mn,H] = deal(zeros(1,m-1));
for i = 1:m-1
    displ = [];
    displ = d(Z(i):Z(i+1));
    mx(i) = max(displ);
    mn(i) = min(displ);
    H(i) = mx(i)-mn(i);  %Response height
end

%Find mean of 1/3 of higheset response heights
H_sort = sort(H);
nr = round((m-1)/3);
H_sort(1:2*nr) = [];
H_s = mean(H_sort);

%Find maximum response ampitude 
mx_extreme = max([mx abs(mn)]);

%When mean value of d is zero, the zeroth moment can be calculated from
%the variance of h
m_0 = var(d);
H_s_var = 4*sqrt(m_0);

%Spectral analysis
df = 1/dt; %sample frequency
[pxx,f] = periodogram(d,[],[],df);
figure
plot(f(1:7000),pxx(1:7000))
%Solving integral m0=int{S(f)df} 
%Using Trapezoidal numerical integration
m0 = trapz(f,pxx);
H_m0=4*sqrt(m_0);

%Pipe dimensions
D = 0.750; %m
r = D/2; 
t = 0.035; %m
A = pi*(r^2-(r-t)^2); %m^2

% Rainflow counting
[c,hist,edges,rmm,idx] = rainflow(d/A,df);

% Stress ranges
range_dynamic = c(:,2);

% Load stress ranges from static analysis
load range_static.txt

% Make histogram 
mx_val = max([max(range_dynamic) max(range_static)]);
figure
histogram(range_dynamic,0:mx_val/40:mx_val)
hold on
histogram(range_static,0:mx_val/40:mx_val)
xlabel('Stress Range')
ylabel('Cycle Counts')
legend('Dynamic','Static')
hold off

% Calculate number of cycles to failure for the stress range corresponding
% to the center of each bar, by use of SN-curve.
for i = 1:length(edges)-1
sigma(i) = edges(i)+(edges(i+1)-edges(i))/2;
end
sigma = sigma/1e6; %MPa
% Parameters used in SN-curve
lga1 = 12.48;
lga2 = 16.13;
m1 = 3;
m2 = 5;
%Solve for N
lgN = lga2 - m2*log10(sigma); 
N = 10.^lgN;

% Number of cycles from in each stress range from rainflow counting
Num = sum(hist,2);
Num = Num';

% Calculating fatigue damage
rel = Num./N;
C = sum(rel);


